Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(160)

Unified Diff: components/crash/content/app/run_as_crashpad_handler_win.h

Issue 2799013002: Monitor crashpad_handler for crashes [sometimes] (Closed)
Patch Set: Address review feedback (scottmg) Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/crash/content/app/run_as_crashpad_handler_win.h
diff --git a/components/crash/content/app/run_as_crashpad_handler_win.h b/components/crash/content/app/run_as_crashpad_handler_win.h
index 8bed61093af320b6871c9650e73060e6dd2a69bc..ade72a01db994c80bdd0c50eba7cc7d22522c980 100644
--- a/components/crash/content/app/run_as_crashpad_handler_win.h
+++ b/components/crash/content/app/run_as_crashpad_handler_win.h
@@ -12,10 +12,15 @@ class CommandLine;
namespace crash_reporter {
// Helper for running an embedded copy of crashpad_handler. Searches for and
// removes --switches::kProcessType=xyz arguments in the command line, and all
// options starting with '/' (for "/prefetch:N"), and then runs
// crashpad::HandlerMain with the remaining arguments.
-int RunAsCrashpadHandler(const base::CommandLine& command_line);
+//
+// Normally, pass switches::kProcessType for process_type_switch. It's accepted
+// as a parameter because this component does not have access to content/, where
+// that variable lives.
+int RunAsCrashpadHandler(const base::CommandLine& command_line,
+ const char* process_type_switch);
} // namespace crash_reporter
« no previous file with comments | « components/crash/content/app/crashpad_win.cc ('k') | components/crash/content/app/run_as_crashpad_handler_win.cc » ('j') | no next file with comments »
@@ -12,10 +12,15 @@ class CommandLine;
namespace crash_reporter {
// Helper for running an embedded copy of crashpad_handler. Searches for and
-// removes --switches::kProcessType=xyz arguments in the command line, and all
+// removes --(process_type_switch)=xyz arguments in the command line, and all
// options starting with '/' (for "/prefetch:N"), and then runs
// crashpad::HandlerMain with the remaining arguments.

Powered by Google App Engine
This is Rietveld 408576698